#[repr(C)]pub struct FluxFileHeader {
pub n_zone: u32,
pub n_fluxes: u32,
}Expand description
Represents the header of a flux file.
This header contains metadata about the flux data stored in the file, including the number of zones and the number of flux interactions.
Fields
n_zone: u32The number of zones in the flux file data.
n_fluxes: u32The number of flux interactions in the file.